# coding: utf-8

"""
    Agilicus API

    Agilicus API endpoints  # noqa: E501

    The version of the OpenAPI document: 2020.06.30
    Contact: dev@agilicus.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import agilicus_api
from agilicus_api.api.challenges_api import ChallengesApi  # noqa: E501
from agilicus_api.rest import ApiException


class TestChallengesApi(unittest.TestCase):
    """ChallengesApi unit test stubs"""

    def setUp(self):
        self.api = agilicus_api.api.challenges_api.ChallengesApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_challenge(self):
        """Test case for create_challenge

        create a challenge  # noqa: E501
        """
        pass

    def test_delete_challenge(self):
        """Test case for delete_challenge

        Delete the challenge specified by challenge_id  # noqa: E501
        """
        pass

    def test_get_answer(self):
        """Test case for get_answer

        answer a challenge  # noqa: E501
        """
        pass

    def test_get_challenge(self):
        """Test case for get_challenge

        Get the challenge specified by challenge_id  # noqa: E501
        """
        pass

    def test_replace_challenge(self):
        """Test case for replace_challenge

        Replace the challenge specified by challenge_id  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



from prettytable import PrettyTable

from . import context
from . import input_helpers


def query(ctx, **kwargs):
    token = context.get_token(ctx)
    apiclient = context.get_apiclient(ctx, token)
    org_id = input_helpers.get_org_from_input_or_ctx(ctx, **kwargs)
    kwargs.pop("org_id", None)
    dt_from = kwargs.pop("dt_from", "now-1day")

    query_results = apiclient.audits_api.list_audits(
        dt_from=dt_from, org_id=org_id, **kwargs
    )

    if query_results:
        return query_results.audits

    return []


def format_audit_list_as_text(audits):
    table = PrettyTable(
        [
            "action",
            "user_id",
            "org_id",
            "source_ip",
            "target_resource_type",
            "target_id",
            "date",
            "trace_id",
        ]
    )
    for record in audits:
        date = "---"
        if record.time:
            date = record.time.strftime("%Y-%m-%d %H:%M:%S %z (%Z)")

        table.add_row(
            [
                record.action,
                record.user_id,
                record.org_id,
                record.source_ip,
                record.target_resource_type,
                record.target_id,
                date,
                record.trace_id,
            ]
        )
    table.align = "l"
    return table
